pyspex
======

Python package pyspex contains software to access and create
SPEXone L1A, L1B and L1C products.

For more information on PACE mission visit:
 * https://pace.gsfc.nasa.gov
 * https://pace.oceansciences.org/mission.htm

For more information on SPEXone instrument visit:
 * https://www.sron.nl/earth-instrument-development/spex/spexone
 * https://pace.oceansciences.org/spexone.htm

The software is intended for SRON internal usage.


Installation
------------
Installation instructions are provided in the INSTALL file.

We installed the software succesfully on Linux, MaxOS and Windows.


Reporting bugs
--------------
email r.m.van.hees[at]sron.nl
